@@ -151,7 +151,21 @@ create_chooser_button (OssoABookSettingsDialog *dialog,
     switch (special_contact)
     {
         case PCR_SPECIAL_CONTACT_UNKNOWN:
-            text = _("Ringtone for contacts not in the address book");
+            /* Note for translators: there is not a lot of horizontal space
+             * for this button, so don't use a much wider strings.
+             * Don't use the "unknown" word to translate this as it would
+             * not be clear. When you receive a phone call from a hidden
+             * number the call UI shows "Unknown number", so in our case
+             * if you use "unknown" it would not be clear if you mean a
+             * caller not in your address book or a contact with hidden
+             * number.
+             * Also, possibly don't use any word referring to phone numbers
+             * as the caller could be using SIP or any voip protocol.
+             * In the worst case try translating "Ringtone for unknown
+             * contact" if it's clear that is the contact that is unknown
+             * and not the calling phone number / ID.
+             * Sorry, I know that it's a pain... */
+            text = _("Ringtone for callers not in your contacts");
             break;
         case PCR_SPECIAL_CONTACT_ANONYMOUS:
             text = _("Ringtone for anonymous callers");
