@@ -69,6 +69,20 @@ aggregator_ready_cb (OssoABookWaitable *aggregator,
         accounts_manager_ready_cb, user_data, NULL);
 }
 
+static gboolean
+quit_idle_cb (gpointer user_data)
+{
+    DEBUG ("SIGUSR1 received, quitting");
+    g_main_loop_quit (loop);
+    return FALSE;
+}
+
+static void
+sigusr1_handler (int signum)
+{
+    g_idle_add (quit_idle_cb, NULL);
+}
+
 int
 main (int    argc,
       char **argv)
@@ -100,12 +114,14 @@ main (int    argc,
 
     ringtoned_profile_init_daemon ();
 
+    signal (SIGUSR1, sigusr1_handler);
+
     g_main_loop_run (loop);
 
     if (dispatcher)
         g_object_unref (dispatcher);
 
-    g_object_unref (loop);
+    g_main_loop_unref (loop);
 
     return 0;
 }
